@@ -1,5 +1,5 @@
-require("ai/include/basic.lua")
-require("ai/personality/trader.lua")
+require 'ai.core.core'
+require 'ai.core.idle.trader'
 
 --[[
  ===FLEE AI===
@@ -10,13 +10,13 @@ Mission specific AI to make pilots leave the system immediately.
 -- Required control rate
 control_rate   = 2
 
-
 -- Required "flee" function
 function create ()
 end
 
 -- Required "control" function
-function control ()
+function control( dt )
+   mem.elapsed = mem.elapsed + dt
    local task  = ai.taskname()
 
    if task ~= "runaway" then
@@ -27,9 +27,9 @@ function control ()
       else
          ai.pushtask("hyperspace" )
       end
-   
+
    elseif task == "runaway" then
-      target = ai.target()
+      local target = ai.taskdata()
 
       if not target:exists() then
          ai.poptask()
@@ -43,8 +43,8 @@ function attacked ( attacker )
    local task = ai.taskname()
 
    if task == "runaway" then
-      local target = ai.target()
-      if target == nil or ai.target() ~= attacker then
+      local target = ai.taskdata()
+      if target == nil or ai.taskdata() ~= attacker then
          ai.poptask()
          ai.pushtask("runaway", attacker)
       end
@@ -52,4 +52,3 @@ function attacked ( attacker )
       ai.pushtask("runaway", attacker)
    end
 end
-
