@@ -1,23 +1,11 @@
 /*
  * See Licensing and Copyright notice in naev.h
  */
-
-
-#ifndef NLUA_GFX_H
-#  define NLUA_GFX_H
-
-
-#include <lua.h>
+#pragma once
 
 #include "nlua.h"
 
-
 /*
  * Library loading
  */
 int nlua_loadGFX( nlua_env env );
-
-
-#endif /* NLUA_GFX_H */
-
-
